;------------------------------------------------------------
;------------------------------------------------------------
;------------------------------------------------------------
;+
;
; @file_comments
; calculate fmask. Economize memory (we do not need to keep vmask anymore)
;
; @categories
; Utilities
;
; @returns
; A 3d array corresponding to vmask.
;
; @examples
; Used like if vmask was a known array by substituing vmask by (vmask())
; For example: Instaed of write vmask[domainef] we have to write (vmask())[domainef]
;
; @history
; Sebastien Masson (smasson@lodyc.jussieu.fr)
;                       11/12/98
;                       20/9/99 cas jpk=1 (merci jpblod@ipsl.jussieu.fr)
;
; @version
; $Id$
;
;-
;------------------------------------------------------------
;------------------------------------------------------------
;------------------------------------------------------------
FUNCTION vmask
;
  compile_opt idl2, strictarrsubs
;
@common
  tempsun = systime(1)          ; For key_performance
;
  CASE size(tmask, /n_dimensions) OF
    2:res = tmask*shift(tmask, 0, -1)
    3:res = tmask*shift(tmask, 0, -1, 0)
  ENDCASE
;
  res[*, jpj-1, *] = vmaskred
  if keyword_set(key_performance) THEN print, 'temps vmask', systime(1)-tempsun 
;
  return, res
end
